@@ -4,7 +4,7 @@ use Mojolicious::Plugin::AssetPack::Asset::Null;
 use Mojolicious::Plugin::AssetPack::Store;
 use Mojolicious::Plugin::AssetPack::Util qw(diag has_ro load_module DEBUG);
 
-our $VERSION = '1.09';
+our $VERSION = '1.10';
 
 has minify => sub { shift->_app->mode eq 'development' ? 0 : 1 };
 
@@ -49,15 +49,14 @@ sub process {
     push @$assets, $asset;
   }
 
-  # hack to enable Reloader to work
-  $self->{input}{$topic} = [@$assets];
-
-  for my $pipe (@{$self->{pipes}}) {
-    next unless $pipe->can('process');
-    local $pipe->{topic} = $topic;
-    diag '%s->process($assets)', ref $pipe if DEBUG;
-    $pipe->process($assets);
-    push @{$self->{asset_paths}}, $_->path for @$assets;
+  for my $method (qw(before_process process after_process)) {
+    for my $pipe (@{$self->{pipes}}) {
+      next unless $pipe->can($method);
+      local $pipe->{topic} = $topic;
+      diag '%s->%s($assets)', ref $pipe, $method if DEBUG;
+      $pipe->$method($assets);
+      push @{$self->{asset_paths}}, $_->path for @$assets;
+    }
   }
 
   $self->_app->log->debug(qq(Processed asset "$topic".));
@@ -221,7 +220,7 @@ Mojolicious::Plugin::AssetPack - Compress and convert css, less, sass, javascrip
 
 =head1 VERSION
 
-1.09
+1.10
 
 =head1 SYNOPSIS
 
